@@ -29,7 +29,7 @@ eris::dictionary::eris
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
@@ -62,3 +62,5 @@ dst_user Destination username
 src_geoip GeoIP Data for the source IP
 dst_geoip GeoIP Data for the destination IP
 attacks Attacks root node
+name Name of the event
+class Class of the event
