@@ -2,7 +2,8 @@ package eris::log;
 
 use Hash::Merge::Simple qw(clone_merge);
 use Moo;
-use Types::Standard qw(ArrayRef HashRef Str);
+use Types::Common::Numeric qw(PositiveNum);
+use Types::Standard qw(ArrayRef HashRef Maybe Str);
 use Ref::Util qw(is_hashref);
 
 use eris::dictionary;
@@ -44,6 +45,18 @@ has tags => (
     lazy    => 1,
     default => sub { [] },
 );
+has total_time => (
+    is  => 'rw',
+    isa => Maybe[PositiveNum],
+);
+has index => (
+    is => 'rw',
+    isa => Maybe[Str],
+);
+has type => (
+    is => 'rw',
+    isa => Maybe[Str],
+);
 
 my $dict;
 
@@ -57,7 +70,7 @@ sub set_decoded {
     foreach my $k (keys %{ $href }) {
         $d->{$k} = $href->{$k};
     }
-    $self->add_context( "decoder::" . $name, $href);
+    $self->add_context($name, $href);
 }
 
 {
@@ -97,8 +110,23 @@ sub set_decoded {
     }
 }
 
+sub add_tags {
+    my ($self,@tags) = @_;
+    my %tags = map { $_ => 1 } @{ $self->tags };
+
+    foreach my $t (@tags) {
+        push @{ $self->tags }, $t unless exists $tags{$t};
+        $tags{$t} = 1;
+    }
+
+    return $self;
+}
+
 sub add_timing {
     my ($self,%args) = @_;
+    if( exists $args{total} ) {
+        $self->total_time( delete $args{total} );
+    }
     my $t = $self->timing;
     push @{ $t },
         map { +{ phase => $_, seconds => $args{$_} } }
@@ -109,9 +137,19 @@ sub add_timing {
 sub as_doc {
     my ($self,%args) = @_;
 
-    my $doc = $self->context;
+    # Default to just the context;
+    my $doc = $args{complete} ? $self->complete : $self->context;
+
+    # Add Metadata
+    if( my $idx = $self->index ) {
+        $doc->{_index} = $idx;
+    }
+    if( my $type = $self->type ) {
+        $doc->{_type} = $type;
+    }
     $doc->{timing} = $self->timing;
     $doc->{tags}   = $self->tags;
+    $doc->{total_time} = $self->total_time if $self->total_time;
 
     return $doc;
 }
@@ -129,7 +167,7 @@ eris::log
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
