@@ -13,7 +13,7 @@ with qw(
 has 'geo_db' => (
     is      => 'ro',
     isa     => Str,
-    default => '/tmp/GeoLite2-City.mmdb',
+    default => '/usr/share/GeoIP/GeoLite2-City.mmdb',
 );
 has 'geo_lookup' => (
     is      => 'ro',
@@ -114,7 +114,7 @@ eris::log::context::GeoIP
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
